@@ -40,4 +40,20 @@
 int corpus_array_grow(void **baseptr, int *sizeptr, size_t width, int count,
 		      int nadd);
 
+
+/**
+ * Grow an big array to accommodate more elements, possibly re-allocating.
+ *
+ * \param baseptr pointer to pointer to first element
+ * \param sizeptr pointer to the capacity (in elements) of the array
+ * \param width size of each element
+ * \param count number of occupied elements
+ * \param nadd number of elements to append after the `count` occupied
+ *        elements
+ *
+ * \returns 0 on success
+ */
+int corpus_bigarray_grow(void **baseptr, size_t *sizeptr, size_t width,
+			 size_t count, size_t nadd);
+
 #endif /* CORPUS_ARRAY_H */
